@@ -172,7 +172,7 @@ es-alias-manager.pl - Allow easy alias management for daily indexes
 
 =head1 VERSION
 
-version 2.3
+version 2.4
 
 =head1 SYNOPSIS
 
@@ -184,16 +184,6 @@ Options:
     --manual            print full manual
     --config            Location of Config File, default /etc/elasticsearch/aliases.yml
 
-From App::ElasticSearch::Utilities:
-
-    --local         Use localhost as the elasticsearch host
-    --host          ElasticSearch host to connect to
-    --port          HTTP port for your cluster
-    --index         Index to run commands against
-    --base          For daily indexes, reference only those starting with "logstash"
-                     (same as --pattern logstash-* or logstash-DATE)
-    --pattern       Use a pattern to operate on the indexes
-
 From CLI::Helpers:
 
     --color             Boolean, enable/disable color, default use git settings
