@@ -188,7 +188,7 @@ es-storage-data.pl - Index pattern-aware elasticsearch storage statistics
 
 =head1 VERSION
 
-version 2.3
+version 2.4
 
 =head1 SYNOPSIS
 
@@ -205,16 +205,6 @@ Options:
     --asc               Sort ascending
     --desc              Sort descending (default)
 
-From App::ElasticSearch::Utilities:
-
-    --local         Use localhost as the elasticsearch host
-    --host          ElasticSearch host to connect to
-    --port          HTTP port for your cluster
-    --index         Index to run commands against
-    --base          For daily indexes, reference only those starting with "logstash"
-                     (same as --pattern logstash-* or logstash-DATE)
-    --pattern       Use a pattern to operate on the indexes
-
 From CLI::Helpers:
 
     --color             Boolean, enable/disable color, default use git settings
